@@ -8,7 +8,7 @@ def check_error(ErrorCode):
     else:
         return False
 
-def help(ErrorCode):
+def help_error(ErrorCode):
     if not check_error(ErrorCode):
         return "EH0 : Codigo de error invalido"
     
@@ -46,3 +46,7 @@ RG = {
 SP = {
     0 : "Necesitas el link de la playlist. Ocurre cuando el link que estas usando no es de una playlist de Spotify"
 }
+
+F = {
+    0 : "Necesitas usar una lista. Ocurre cuando pasas algo diferente del tipo <list> a una funcion"
+}
\ No newline at end of file
